Index: pkg/dartino_compiler/lib/src/enqueuer_mixin.dart |
diff --git a/pkg/fletchc/lib/src/enqueuer_mixin.dart b/pkg/dartino_compiler/lib/src/enqueuer_mixin.dart |
similarity index 98% |
rename from pkg/fletchc/lib/src/enqueuer_mixin.dart |
rename to pkg/dartino_compiler/lib/src/enqueuer_mixin.dart |
index e0bbd408cbba85d0bd240e38825c47bda33bd40d..b2ccbe79e5904ac775e65596cdee5be1ded0ed8d 100644 |
--- a/pkg/fletchc/lib/src/enqueuer_mixin.dart |
+++ b/pkg/dartino_compiler/lib/src/enqueuer_mixin.dart |
@@ -2,9 +2,9 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE.md file. |
// TODO(ahe): Get rid of this file. Perhaps by having [FletchEnqueuer] extend |
// [CodegenEnqueuer]. |
-part of fletchc.fletch_enqueuer; |
+part of dartino_compiler.dartino_enqueuer; |
get notImplemented => throw "not implemented"; |
@@ -2,9 +2,9 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE.md file. |
-// TODO(ahe): Get rid of this file. Perhaps by having [FletchEnqueuer] extend |
+// TODO(ahe): Get rid of this file. Perhaps by having [DartinoEnqueuer] extend |
// [CodegenEnqueuer]. |